"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const base_1 = require("../../../src/base");
const tools_1 = require("../../../src/tools");
const SpecHelpers_1 = require("../../SpecHelpers");
const SPECS_DATA_BASE_DIRECTORY = SpecHelpers_1.SpecHelpers.getSpecsDataBaseDirectory();
const basicInput = SPECS_DATA_BASE_DIRECTORY + "/combineTilesets/nestedExternal";
const basicOutput = SPECS_DATA_BASE_DIRECTORY + "/output/combineTilesets/nestedExternal";
const overwrite = true;
describe("TilesetCombiner", function () {
    afterEach(function () {
        SpecHelpers_1.SpecHelpers.forceDeleteDirectory(SPECS_DATA_BASE_DIRECTORY + "/output/combineTilesets");
    });
    it("combines external tilesets into a single tileset", async function () {
        await tools_1.TilesetOperations.combine(basicInput, basicOutput, overwrite);
        // Ensure that the output directory contains the expected files:
        // All files of the input, except for the external tileset JSON files
        const actualRelativeFiles = SpecHelpers_1.SpecHelpers.collectRelativeFileNames(basicOutput);
        actualRelativeFiles.sort();
        const expectedRelativeFiles = [
            "README.md",
            "sub0/sub01/tileD.b3dm",
            "sub0/tileC.b3dm",
            "sub1/sub10/tileF.b3dm",
            "sub1/tileE.b3dm",
            "tileA.b3dm",
            "tileB.b3dm",
            "tileset.json",
        ];
        expect(actualRelativeFiles).toEqual(expectedRelativeFiles);
        // Ensure that the single 'tileset.json' contains the
        // proper content URIs for the combined output
        const tilesetJsonBuffer = fs_1.default.readFileSync(base_1.Paths.join(basicOutput, "tileset.json"));
        const tileset = JSON.parse(tilesetJsonBuffer.toString());
        const actualContentUris = await SpecHelpers_1.SpecHelpers.collectExplicitContentUris(tileset.root);
        actualContentUris.sort();
        const expectedContentUris = [
            "sub0/sub01/tileD.b3dm",
            "sub0/tileC.b3dm",
            "sub1/sub10/tileF.b3dm",
            "sub1/tileE.b3dm",
            "tileA.b3dm",
            "tileB.b3dm",
        ];
        expect(actualContentUris).toEqual(expectedContentUris);
    });
});
//# sourceMappingURL=TilesetCombinerSpec.js.map