/// <reference types="node" />
import { Document } from "@gltf-transform/core";
/**
 * Methods for obtaining a valid glTF-Transform document from
 * inputs that may contain legacy data.
 *
 * This is intended for cases where the data has to be upgraded
 * by preprocessing the input (for example, to convert a glTF 1.0
 * GLB to glTF 2.0), or by post-processing the document (for example,
 * to convert legacy representations of data (like 2D oct-encoded
 * normals) into the expected representation).
 *
 * @internal
 */
export declare class GltfUpgrade {
    static obtainDocument(glb: Buffer): Promise<Document>;
    /**
     * Check each mesh primitive in the given document, to see if it
     * contains a VEC2/BYTE or VEC2/SHORT accessor for the NORMAL.
     * If it does, then this accessor will be replaced by one that
     * contains the decoded 3D normals.
     *
     * (Note that the old accessors might become unused by that.
     * The document should afterwards be cleaned up with
     * glTF-Transform 'prune()')
     *
     * @param document - The glTF-Transform document
     */
    private static octDecode2DNormals;
    /**
     * Decode the oct-encoded (2D) normals from the given accessor, and
     * return the result as a new accessor.
     *
     * @param document - The glTF-Transform document
     * @param encodedAccessor - The (VEC2) accessor containing the
     * oct-encoded 2D normal data
     * @param range - The decoding range: 255 for BYTE, 65535 for SHORT
     * @returns The decoded (VEC3/FLOAT) accessor.
     */
    private static octDecodeAccessor;
    /**
     * Oct-decode the given 2D normal from the given value range into
     * a 3D normal.
     *
     * @param encoded - The encoded normal as a 2-element array
     * @param range - The decoding range: 255 for BYTE, 65535 for SHORT
     * @returns The decoded normal as a 3-element array
     */
    private static octDecode;
}
//# sourceMappingURL=GltfUpgrade.d.ts.map